Render membrane drawable trees to java.awt.image.BufferedImage via membrane's Java2D backend. Faster than SVG for large plots and produces raster output that Clay renders automatically.
Render membrane drawable trees to java.awt.image.BufferedImage via membrane's Java2D backend. Faster than SVG for large plots and produces raster output that Clay renders automatically.
(save-png img path)Save a BufferedImage to a PNG file. Returns the path.
Save a BufferedImage to a PNG file. Returns the path.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |