scicloj.plotje.impl.coord


make-coordcljmultimethod

Build a coordinate function: (coord data-x data-y) -> [pixel-x pixel-y].

Build a coordinate function: (coord data-x data-y) -> [pixel-x pixel-y].
sourceraw docstring

make-coord-pxcljmultimethod

Build a pixel-space reprojection function for coordinate systems that need arc interpolation (e.g. polar). Returns nil for systems where bars can be drawn as simple rectangles.

Build a pixel-space reprojection function for coordinate systems that need
arc interpolation (e.g. polar). Returns nil for systems where bars can be
drawn as simple rectangles.
sourceraw docstring

show-ticks?cljmultimethod

Whether to show tick labels for this coordinate system.

Whether to show tick labels for this coordinate system.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries