Build a coordinate function: (coord data-x data-y) -> [pixel-x pixel-y].
Build a coordinate function: (coord data-x data-y) -> [pixel-x pixel-y].
Build a pixel-space reprojection function for coordinate systems that need arc interpolation (e.g. polar). Returns nil for systems where bars can be drawn as simple rectangles.
Build a pixel-space reprojection function for coordinate systems that need arc interpolation (e.g. polar). Returns nil for systems where bars can be drawn as simple rectangles.
Whether to show tick labels for this coordinate system.
Whether to show tick labels for this coordinate system.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |