scicloj.plotje.impl.extract

Extract data-space geometry from resolved draft layers and stat results. Produces layer descriptor maps — plain Clojure maps with mark type, style, and groups of data-space coordinates.

Extract data-space geometry from resolved draft layers and stat results.
Produces layer descriptor maps — plain Clojure maps with mark type,
style, and groups of data-space coordinates.
raw docstring

extract-layercljmultimethod

Extract data-space geometry from a resolved draft layer and its stat result. Returns a layer descriptor map.

Extract data-space geometry from a resolved draft layer and its stat result.
Returns a layer descriptor map.
sourceraw docstring

resolve-colorclj

(resolve-color all-colors color-val fixed-color cfg)

Resolve a color value to [r g b a]. Handles column values, fixed colors, and defaults.

Resolve a color value to [r g b a]. Handles column values, fixed colors, and defaults.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries