Convert a membrane drawable tree into a figure for the given format. Dispatches on the format keyword (:svg, etc.).
The :default defmethod loads renderer namespaces on demand for
formats listed in known-render-namespaces.
Convert a membrane drawable tree into a figure for the given format. Dispatches on the format keyword (:svg, etc.). The :default defmethod loads renderer namespaces on demand for formats listed in `known-render-namespaces`.
Convert a plan into a figure for the given format. Returns format-specific output (e.g., SVG hiccup, Plotly spec). Dispatches on the format keyword (:svg, :plotly, etc.).
The :default defmethod loads renderer namespaces on demand for
formats listed in known-render-namespaces.
Convert a plan into a figure for the given format. Returns format-specific output (e.g., SVG hiccup, Plotly spec). Dispatches on the format keyword (:svg, :plotly, etc.). The :default defmethod loads renderer namespaces on demand for formats listed in `known-render-namespaces`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |