Compute a statistical transform for a draft-layer.
Compute a statistical transform for a draft-layer.
(fit-lm xs-col ys-col)Fit a linear model, return {:x1 :y1 :x2 :y2}.
Fit a linear model, return {:x1 :y1 :x2 :y2}.
(fit-lm-with-se xs-col ys-col n-grid level)Fit a linear model and compute confidence band on a grid of x-values. Returns {:xs [...] :ys [...] :ymins [...] :ymaxs [...] :x1 :y1 :x2 :y2}.
Fit a linear model and compute confidence band on a grid of x-values.
Returns {:xs [...] :ys [...] :ymins [...] :ymaxs [...] :x1 :y1 :x2 :y2}.(fit-loess xs-col ys-col n-grid bandwidth)Fit a LOESS curve, return {:xs ... :ys ...} evaluated on a grid.
Fit a LOESS curve, return {:xs ... :ys ...} evaluated on a grid.
(fit-loess-with-se xs-col ys-col n-grid bandwidth level n-boot)Fit LOESS with bootstrap confidence band. Returns {:xs :ys :ymins :ymaxs} evaluated on a grid.
Fit LOESS with bootstrap confidence band. Returns
{:xs :ys :ymins :ymaxs} evaluated on a grid.(group-by-columns ds group-cols f)Split dataset by grouping columns, apply f to each group.
Iterates groups in the order they first appear in the dataset, so
results are deterministic regardless of tc/group-by's underlying
map type (which is a PersistentHashMap, scrambled by murmur3 hash
for >8 groups). This also preserves user-visible stacking and
draw order.
Split dataset by grouping columns, apply f to each group. Iterates groups in the order they first appear in the dataset, so results are deterministic regardless of `tc/group-by`'s underlying map type (which is a PersistentHashMap, scrambled by murmur3 hash for >8 groups). This also preserves user-visible stacking and draw order.
(numeric-extent col)Min/max pair from a numeric column.
Min/max pair from a numeric column.
(prepare-points draft-layer)Clean data, compute domains, group by columns. Drops rows with missing values in x/y AND in any referenced numeric aesthetic column (color/size/alpha/y-min/y-max/fill) so downstream code never sees nil/NaN values where it tries to coerce to double.
Clean data, compute domains, group by columns. Drops rows with missing values in x/y AND in any referenced numeric aesthetic column (color/size/alpha/y-min/y-max/fill) so downstream code never sees nil/NaN values where it tries to coerce to double.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |